@@ -6,11 +6,14 @@ from typing import Dict
 
 from deepdriver.sdk import util
 from deepdriver import logger
-
+import deepdriver.version as version
 URL_LOGIN = "/api/client/auth"
 URL_CREATE = "/api/client/experiment/create"
+URL_CREATE_HPO = "/api/client/experiment/create/hpo"
 URL_FINISH = "/api/client/run/finish"
 
+
+
 jwt_key: str = None
 
 def set_jwt_key(jwt_key_: str) -> None:
@@ -50,7 +53,6 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
     }
 
     # Interface.py의 init 함수 호출 후 응답받은 데이터로 부터 실험환경 이름과 팀이름, 실행이름, 실행ID, 대쉬보드URL을 가져와 Run 객체에 설정하고 반환한다.
-    import deepdriver.version as version
     data = {
         "teamName": team_name,
         "expName": exp_name,
@@ -64,6 +66,28 @@ def init(http_host: str ,exp_name: str="", team_name: str="", run_name: str="",
     logger.debug("init() response : " + rsp["message"])
     return rsp
 
+def create_hpo(http_host:str, exp_name: str="", team_name: str="", hpo_config: Dict=None):
+
+    data ={
+        "teamName": team_name,
+        "expName": exp_name,
+        "config":  {"cliVer": version.__version__, "pythonVer": util.get_python_version(), "hpoConfig": hpo_config},
+        "sysInfo": {
+            "os": util.get_os(),
+            "python": util.get_python_version(),
+            "gpu": util.get_gpu(),
+            "gpuCount": util.get_gpu_count(),
+            "cpuCount": util.get_cpu_count(),
+            "hostname": util.get_hostname(),
+        },
+    }
+    url = ParseResult(scheme="http", netloc=http_host, path=URL_CREATE_HPO, params='', query='', fragment='').geturl()
+    rsp = post(url, data)
+    logger.debug("create_hpo() response : " + rsp["message"])
+    return rsp
+    # get_jwt_key()
+
+
 def finish(http_host: str ,data: Dict) -> Dict:
     url = ParseResult(scheme="http",netloc=http_host, path=URL_FINISH, params='', query='', fragment='').geturl()
     rsp = post(url, data)
@@ -71,7 +95,7 @@ def finish(http_host: str ,data: Dict) -> Dict:
     return rsp
 
 def post(url: str, data: Dict) -> Dict:
-    logger.debug(f"REST[POST] to [{url}] : data=[{data}]")
+    logger.debug(f"REST[POST] to [{url}] : data=[{json.dumps(data)}], headers=[{get_headers()}")
     rsp = requests.post(url, headers=get_headers(), data=json.dumps(data))
     if rsp.status_code not in [200, 201]:
         logger.error(f"post({url}) failed({rsp.status_code})")
