@@ -4,7 +4,7 @@ from __future__ import annotations
 import json
 import os
 import sys
-from typing import Any, Dict, List, Tuple, TYPE_CHECKING, Union
+from typing import Dict, List, Tuple, TYPE_CHECKING, Union
 from urllib.parse import urlsplit, urlparse
 
 import grpc
@@ -343,6 +343,8 @@ def login(key: str) -> bool:
 def init(exp_name: str = "", team_name: str = "", run_name: str = "", config: Dict = None) -> Dict:
     return http_interface.init(get_http_host(), exp_name, team_name, run_name, config)
 
+def create_hpo(exp_name: str = "", team_name: str = "", hpo_config: Dict = None) -> Dict:
+    return http_interface.create_hpo(get_http_host(), exp_name, team_name, hpo_config)
 
 def finish(data: Dict) -> Dict:
     return http_interface.finish(get_http_host(), data)
